diff --git a/.github/workflows/bootstrap.yaml b/.github/workflows/bootstrap.yaml
index 99c9ea57ef8a12b5a02a391769494666edaccdb0..8fe7f738c6abe54d2aa028ad94134d15856fa8e2 100644
--- a/.github/workflows/bootstrap.yaml
+++ b/.github/workflows/bootstrap.yaml
@@ -49,7 +49,7 @@ jobs:
           GITHUB_TOKEN: ${{ secrets.GITPROVIDER_BOT_TOKEN }}
       - name: uninstall
         run: |
-          ./bin/gotk suspend kustomization gotk-system
+          ./bin/gotk suspend kustomization flux-system
           ./bin/gotk uninstall --resources --crds -s
       - name: bootstrap reinstall
         run: |
@@ -73,6 +73,6 @@ jobs:
       - name: Debug failure
         if: failure()
         run: |
-          kubectl -n gotk-system get all
-          kubectl -n gotk-system logs deploy/source-controller
-          kubectl -n gotk-system logs deploy/kustomize-controller
+          kubectl -n flux-system get all
+          kubectl -n flux-system logs deploy/source-controller
+          kubectl -n flux-system logs deploy/kustomize-controller
diff --git a/.github/workflows/e2e.yaml b/.github/workflows/e2e.yaml
index 4ccb486fab51467922de1096e1d8152283311446..1945174e0e9263d4b12c7132b5c75512b5896859 100644
--- a/.github/workflows/e2e.yaml
+++ b/.github/workflows/e2e.yaml
@@ -146,7 +146,7 @@ jobs:
         if: failure()
         run: |
           kubectl version --client --short
-          kubectl -n gotk-system get all
-          kubectl -n gotk-system get kustomizations -oyaml
-          kubectl -n gotk-system logs deploy/source-controller
-          kubectl -n gotk-system logs deploy/kustomize-controller
+          kubectl -n flux-system get all
+          kubectl -n flux-system get kustomizations -oyaml
+          kubectl -n flux-system logs deploy/source-controller
+          kubectl -n flux-system logs deploy/kustomize-controller
diff --git a/cmd/gotk/create_alert.go b/cmd/gotk/create_alert.go
index e307747d2afe28cb8858466f6ecaf6cc48c44d2c..edd1634e41e9da6a240249d71baab66ece758095 100644
--- a/cmd/gotk/create_alert.go
+++ b/cmd/gotk/create_alert.go
@@ -41,9 +41,9 @@ var createAlertCmd = &cobra.Command{
 	Example: `  # Create an Alert for kustomization events
   gotk create alert \
   --event-severity info \
-  --event-source Kustomization/gotk-system \
+  --event-source Kustomization/flux-system \
   --provider-ref slack \
-  gotk-system
+  flux-system
 `,
 	RunE: createAlertCmdRun,
 }
diff --git a/cmd/gotk/main.go b/cmd/gotk/main.go
index ef974fe07f3ae8491ba1f6f4d80a9b7622ade12a..7555dc7f9d75d4511efa466c5436b9c21c83aee5 100644
--- a/cmd/gotk/main.go
+++ b/cmd/gotk/main.go
@@ -17,7 +17,6 @@ limitations under the License.
 package main
 
 import (
-	"github.com/fluxcd/toolkit/pkg/manifestgen/install"
 	"log"
 	"os"
 	"path/filepath"
@@ -28,6 +27,7 @@ import (
 	_ "k8s.io/client-go/plugin/pkg/client/auth"
 
 	gotklog "github.com/fluxcd/toolkit/pkg/log"
+	"github.com/fluxcd/toolkit/pkg/manifestgen/install"
 )
 
 var VERSION = "0.0.0-dev.0"
@@ -55,7 +55,7 @@ var rootCmd = &cobra.Command{
   gotk get sources git
 
   # Trigger a GitRepository source reconciliation
-  gotk reconcile source git gotk-system
+  gotk reconcile source git flux-system
 
   # Export GitRepository sources in YAML format
   gotk export source git --all > sources.yaml
diff --git a/cmd/gotk/uninstall.go b/cmd/gotk/uninstall.go
index 59dba91e48e09c9be86ae4ff931a893fc41f1571..8576cd3796db4a396534c0cec0390bd2e5978d08 100644
--- a/cmd/gotk/uninstall.go
+++ b/cmd/gotk/uninstall.go
@@ -37,10 +37,10 @@ var uninstallCmd = &cobra.Command{
 	Short: "Uninstall the toolkit components",
 	Long:  "The uninstall command removes the namespace, cluster roles, cluster role bindings and CRDs from the cluster.",
 	Example: `  # Dry-run uninstall of all components
-  gotk uninstall --dry-run --namespace=gotk-system
+  gotk uninstall --dry-run --namespace=flux-system
 
   # Uninstall all components and delete custom resource definitions
-  gotk uninstall --resources --crds --namespace=gotk-system
+  gotk uninstall --resources --crds --namespace=flux-system
 `,
 	RunE: uninstallCmdRun,
 }
diff --git a/docs/cmd/gotk.md b/docs/cmd/gotk.md
index 09adf7b6bea187c9281c406a430ef89db5283d25..046fe5fa1891c5a881a377c9e9a694382abd286a 100644
--- a/docs/cmd/gotk.md
+++ b/docs/cmd/gotk.md
@@ -25,7 +25,7 @@ Command line utility for assembling Kubernetes CD pipelines the GitOps way.
   gotk get sources git
 
   # Trigger a GitRepository source reconciliation
-  gotk reconcile source git gotk-system
+  gotk reconcile source git flux-system
 
   # Export GitRepository sources in YAML format
   gotk export source git --all > sources.yaml
@@ -69,7 +69,7 @@ Command line utility for assembling Kubernetes CD pipelines the GitOps way.
 ```
   -h, --help                help for gotk
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_bootstrap.md b/docs/cmd/gotk_bootstrap.md
index c171595ec16a331326bc189c1fb70116ea7a8bd1..9e622c92a44298362327b3e7ab62a05b9b3e1167 100644
--- a/docs/cmd/gotk_bootstrap.md
+++ b/docs/cmd/gotk_bootstrap.md
@@ -25,7 +25,7 @@ The bootstrap sub-commands bootstrap the toolkit components on the targeted Git
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_bootstrap_github.md b/docs/cmd/gotk_bootstrap_github.md
index f2675cfc76360cc78473b4b665e447727352585a..7630e27d8ef11760df4d99621ca06ebba0dfc8b8 100644
--- a/docs/cmd/gotk_bootstrap_github.md
+++ b/docs/cmd/gotk_bootstrap_github.md
@@ -63,7 +63,7 @@ gotk bootstrap github [flags]
       --image-pull-secret string   Kubernetes secret name used for pulling the toolkit images from a private registry
       --kubeconfig string          path to the kubeconfig file (default "~/.kube/config")
       --log-level logLevel         log level, available options are: (debug, info, error) (default info)
-  -n, --namespace string           the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string           the namespace scope for this operation (default "flux-system")
       --network-policy             deny ingress access to the toolkit controllers from other namespaces using network policies (default true)
       --registry string            container registry where the toolkit images are published (default "ghcr.io/fluxcd")
       --timeout duration           timeout for this operation (default 5m0s)
diff --git a/docs/cmd/gotk_bootstrap_gitlab.md b/docs/cmd/gotk_bootstrap_gitlab.md
index e9a1108c1fbf4c698cedc3686c9fbef2baf71528..3ef87b22715fe58e2ffca75b436f811bb60c9871 100644
--- a/docs/cmd/gotk_bootstrap_gitlab.md
+++ b/docs/cmd/gotk_bootstrap_gitlab.md
@@ -63,7 +63,7 @@ gotk bootstrap gitlab [flags]
       --image-pull-secret string   Kubernetes secret name used for pulling the toolkit images from a private registry
       --kubeconfig string          path to the kubeconfig file (default "~/.kube/config")
       --log-level logLevel         log level, available options are: (debug, info, error) (default info)
-  -n, --namespace string           the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string           the namespace scope for this operation (default "flux-system")
       --network-policy             deny ingress access to the toolkit controllers from other namespaces using network policies (default true)
       --registry string            container registry where the toolkit images are published (default "ghcr.io/fluxcd")
       --timeout duration           timeout for this operation (default 5m0s)
diff --git a/docs/cmd/gotk_check.md b/docs/cmd/gotk_check.md
index 6d306cf786d458675104b7cae541d3c3b1e266b4..b20823af29ebe2780e0ad0ae6e729d3828644b53 100644
--- a/docs/cmd/gotk_check.md
+++ b/docs/cmd/gotk_check.md
@@ -34,7 +34,7 @@ gotk check [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_completion.md b/docs/cmd/gotk_completion.md
index a164ee1f325acaf90639b0ff49825c825df54e89..6bdb75edf7429c37923298e570d24bd14021dd32 100644
--- a/docs/cmd/gotk_completion.md
+++ b/docs/cmd/gotk_completion.md
@@ -16,7 +16,7 @@ The completion sub-command generates completion scripts for various shells
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_completion_bash.md b/docs/cmd/gotk_completion_bash.md
index 3ee55e9d8a36999b77794d0308dbd8955b7162cb..4fead0061c36183176552fd52d5ba21593e7e7d0 100644
--- a/docs/cmd/gotk_completion_bash.md
+++ b/docs/cmd/gotk_completion_bash.md
@@ -34,7 +34,7 @@ command -v gotk >/dev/null && . <(gotk completion bash)
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_completion_fish.md b/docs/cmd/gotk_completion_fish.md
index eb8ecae19f857827b6b260529c8d1194e792608f..4c636f9810a52337c31d7f3e26f4d0979693b02a 100644
--- a/docs/cmd/gotk_completion_fish.md
+++ b/docs/cmd/gotk_completion_fish.md
@@ -35,7 +35,7 @@ See http://fishshell.com/docs/current/index.html#completion-own for more details
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_completion_powershell.md b/docs/cmd/gotk_completion_powershell.md
index d1a5fe7634b6337dbb397c32bab8d6f8fd827262..65621e0aa526047f3327c53e846e0de8e2b055c6 100644
--- a/docs/cmd/gotk_completion_powershell.md
+++ b/docs/cmd/gotk_completion_powershell.md
@@ -41,7 +41,7 @@ gotk completion >> gotk-completions.ps1
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_completion_zsh.md b/docs/cmd/gotk_completion_zsh.md
index e931e044373113d9e276a0e36736f5943c96203b..fa63d644af8293b07b1eb43e93d9feacd1e5e1b7 100644
--- a/docs/cmd/gotk_completion_zsh.md
+++ b/docs/cmd/gotk_completion_zsh.md
@@ -42,7 +42,7 @@ mv _gotk ~/.zprezto/modules/completion/external/src/  # zprezto
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create.md b/docs/cmd/gotk_create.md
index c7dcc42a229ba83861d4fcea0c2e8f1a16a15976..8f8c1d36961e4db6ef5162ce87e0563dfd32c8fa 100644
--- a/docs/cmd/gotk_create.md
+++ b/docs/cmd/gotk_create.md
@@ -19,7 +19,7 @@ The create sub-commands generate sources and resources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_alert-provider.md b/docs/cmd/gotk_create_alert-provider.md
index 995520238f3763048291f587740c158ebe3282fd..53f3f141939e4fd44bbc0eb6aa33ec5b60430a07 100644
--- a/docs/cmd/gotk_create_alert-provider.md
+++ b/docs/cmd/gotk_create_alert-provider.md
@@ -46,7 +46,7 @@ gotk create alert-provider [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_alert.md b/docs/cmd/gotk_create_alert.md
index 3b1e2adc9314910fb45df48383530a09cf42caac..edf9ff321f5c3c7fdfa647f861c3b732e7efa181 100644
--- a/docs/cmd/gotk_create_alert.md
+++ b/docs/cmd/gotk_create_alert.md
@@ -16,9 +16,9 @@ gotk create alert [name] [flags]
   # Create an Alert for kustomization events
   gotk create alert \
   --event-severity info \
-  --event-source Kustomization/gotk-system \
+  --event-source Kustomization/flux-system \
   --provider-ref slack \
-  gotk-system
+  flux-system
 
 ```
 
@@ -38,7 +38,7 @@ gotk create alert [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_helmrelease.md b/docs/cmd/gotk_create_helmrelease.md
index cbd86586857fed4d5034986b3bb00db0288ed313..33d45dba374c87632254312ba7efaa7f0048d090 100644
--- a/docs/cmd/gotk_create_helmrelease.md
+++ b/docs/cmd/gotk_create_helmrelease.md
@@ -79,7 +79,7 @@ gotk create helmrelease [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_kustomization.md b/docs/cmd/gotk_create_kustomization.md
index 8df99f401c776d03f25f33c7172a389b1a4ad692..b7286732480c6645bd133cd1d491b910ca101f5b 100644
--- a/docs/cmd/gotk_create_kustomization.md
+++ b/docs/cmd/gotk_create_kustomization.md
@@ -65,7 +65,7 @@ gotk create kustomization [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_receiver.md b/docs/cmd/gotk_create_receiver.md
index d6d053b92e4db261c4d45271c75d76c8051a9545..a811fcb99d0ffa2b791eebe3363b9bd916aa20ee 100644
--- a/docs/cmd/gotk_create_receiver.md
+++ b/docs/cmd/gotk_create_receiver.md
@@ -41,7 +41,7 @@ gotk create receiver [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_source.md b/docs/cmd/gotk_create_source.md
index 2871da882d0f975a0e3766bb4073fe6643d1261e..1878790cf8896c8b792f87991848bc3a85772573 100644
--- a/docs/cmd/gotk_create_source.md
+++ b/docs/cmd/gotk_create_source.md
@@ -19,7 +19,7 @@ The create source sub-commands generate sources.
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_source_bucket.md b/docs/cmd/gotk_create_source_bucket.md
index abfa06f720cb5fc8083fb2e45450d105f30e9cbb..65c944fd6c02893cf6433a7b06fd27afad4806e3 100644
--- a/docs/cmd/gotk_create_source_bucket.md
+++ b/docs/cmd/gotk_create_source_bucket.md
@@ -55,7 +55,7 @@ gotk create source bucket [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_source_git.md b/docs/cmd/gotk_create_source_git.md
index 4ee59b48f60d7baad1b847882371cfe2dc7cba29..00b1cb322feb63ba0ed61c2d145140db9e3ce685 100644
--- a/docs/cmd/gotk_create_source_git.md
+++ b/docs/cmd/gotk_create_source_git.md
@@ -75,7 +75,7 @@ gotk create source git [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_create_source_helm.md b/docs/cmd/gotk_create_source_helm.md
index b3baeb1c7d89c2351dde9fb000f366f5dc70ddf0..83d351ed9318b5b9558bc2daf6d9490647bc4545 100644
--- a/docs/cmd/gotk_create_source_helm.md
+++ b/docs/cmd/gotk_create_source_helm.md
@@ -55,7 +55,7 @@ gotk create source helm [name] [flags]
       --interval duration   source sync interval (default 1m0s)
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
       --label strings       set labels on the resource (can specify multiple labels with commas: label1=value1,label2=value2)
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_delete.md b/docs/cmd/gotk_delete.md
index 7f9bc14426b1c5b92eea25d8ab31bc58a0a6ea60..4336517a5c6a111c3812fd8bc9029a2034fddf67 100644
--- a/docs/cmd/gotk_delete.md
+++ b/docs/cmd/gotk_delete.md
@@ -17,7 +17,7 @@ The delete sub-commands delete sources and resources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_delete_alert-provider.md b/docs/cmd/gotk_delete_alert-provider.md
index b380a787256c7819cef8622c68ce7a0e262967dc..b0ca34feff7af7a022b6bc42a6ea44847b1b7114 100644
--- a/docs/cmd/gotk_delete_alert-provider.md
+++ b/docs/cmd/gotk_delete_alert-provider.md
@@ -28,7 +28,7 @@ gotk delete alert-provider [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_alert.md b/docs/cmd/gotk_delete_alert.md
index 8feaa70bd3294c064c65fa776a5efd9f53cd1c76..a1cca380fba3f018d3d004c70fe9b376e96a2816 100644
--- a/docs/cmd/gotk_delete_alert.md
+++ b/docs/cmd/gotk_delete_alert.md
@@ -28,7 +28,7 @@ gotk delete alert [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_helmrelease.md b/docs/cmd/gotk_delete_helmrelease.md
index a8d5442307cfbe4901380fe9bff36a2f4000ee82..6ae3031c6b13b04121cbd57696e1b6e71ad12390 100644
--- a/docs/cmd/gotk_delete_helmrelease.md
+++ b/docs/cmd/gotk_delete_helmrelease.md
@@ -28,7 +28,7 @@ gotk delete helmrelease [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_kustomization.md b/docs/cmd/gotk_delete_kustomization.md
index a76da60b423a6fa440a420f818adda6c2e2d3724..463b31a4bb252ff66a789129d289bfaf3f4fb4a7 100644
--- a/docs/cmd/gotk_delete_kustomization.md
+++ b/docs/cmd/gotk_delete_kustomization.md
@@ -28,7 +28,7 @@ gotk delete kustomization [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_receiver.md b/docs/cmd/gotk_delete_receiver.md
index 063ec5c330c1ea8811003dad94d3b540305eed55..1c20287d6656f8b2f1c3faf883370e4c329d3e96 100644
--- a/docs/cmd/gotk_delete_receiver.md
+++ b/docs/cmd/gotk_delete_receiver.md
@@ -28,7 +28,7 @@ gotk delete receiver [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_source.md b/docs/cmd/gotk_delete_source.md
index 3088dbe327478628c94903e5765082f8eff2bb1f..ad1b525f89640820f2f6e78a1459a0963cb55688 100644
--- a/docs/cmd/gotk_delete_source.md
+++ b/docs/cmd/gotk_delete_source.md
@@ -16,7 +16,7 @@ The delete source sub-commands delete sources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_source_bucket.md b/docs/cmd/gotk_delete_source_bucket.md
index 7745e5cbfc6e094c9e0df23206e608241f6eec14..5913f6626c218449c07b7a769868993b606b624d 100644
--- a/docs/cmd/gotk_delete_source_bucket.md
+++ b/docs/cmd/gotk_delete_source_bucket.md
@@ -28,7 +28,7 @@ gotk delete source bucket [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_source_git.md b/docs/cmd/gotk_delete_source_git.md
index e21426a62da6dd14abe7c9a3f12420f63d15c893..f0315fdbcd91302f34ef28df0e5104e8937c1e7e 100644
--- a/docs/cmd/gotk_delete_source_git.md
+++ b/docs/cmd/gotk_delete_source_git.md
@@ -28,7 +28,7 @@ gotk delete source git [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_delete_source_helm.md b/docs/cmd/gotk_delete_source_helm.md
index a095c255da0af6f761b6a39cc89cd47237f19a5e..5d96d882fdba4a88b6b7b96e9dbde86e3b587472 100644
--- a/docs/cmd/gotk_delete_source_helm.md
+++ b/docs/cmd/gotk_delete_source_helm.md
@@ -28,7 +28,7 @@ gotk delete source helm [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
   -s, --silent              delete resource without asking for confirmation
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
diff --git a/docs/cmd/gotk_export.md b/docs/cmd/gotk_export.md
index e312609dd91f0b20dc2afb11f9ae27bc2f284bd6..01b20b2d550c76f25e333d39434799530981db47 100644
--- a/docs/cmd/gotk_export.md
+++ b/docs/cmd/gotk_export.md
@@ -17,7 +17,7 @@ The export sub-commands export resources in YAML format.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_alert-provider.md b/docs/cmd/gotk_export_alert-provider.md
index f465b79f0eb6d6437e2c35c7edb455ecbf3ad404..96fc18045c59e130999b300f25890f2dbd52eff8 100644
--- a/docs/cmd/gotk_export_alert-provider.md
+++ b/docs/cmd/gotk_export_alert-provider.md
@@ -32,7 +32,7 @@ gotk export alert-provider [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_alert.md b/docs/cmd/gotk_export_alert.md
index 86222f76a2b8eaab3bd695d95a3555cdbf5f0847..376154372b79baf33851ec195ffafffde0ad0ddb 100644
--- a/docs/cmd/gotk_export_alert.md
+++ b/docs/cmd/gotk_export_alert.md
@@ -32,7 +32,7 @@ gotk export alert [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_helmrelease.md b/docs/cmd/gotk_export_helmrelease.md
index 779efdf71f87eca772128a2f34634454752731ef..bf1924686c52ce4e3b611c30ed4bf9f0da9ed825 100644
--- a/docs/cmd/gotk_export_helmrelease.md
+++ b/docs/cmd/gotk_export_helmrelease.md
@@ -32,7 +32,7 @@ gotk export helmrelease [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_kustomization.md b/docs/cmd/gotk_export_kustomization.md
index b9c14339e277db72d1524db07922336e81e05ccc..5711619748a1e32e696b3f30bd8655896fb62349 100644
--- a/docs/cmd/gotk_export_kustomization.md
+++ b/docs/cmd/gotk_export_kustomization.md
@@ -32,7 +32,7 @@ gotk export kustomization [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_receiver.md b/docs/cmd/gotk_export_receiver.md
index 2d884c57dcb4034c4b90c36d74d829785ca1a1b1..93bbcaed1c7803bbc56fd3f698978ea9456e0109 100644
--- a/docs/cmd/gotk_export_receiver.md
+++ b/docs/cmd/gotk_export_receiver.md
@@ -32,7 +32,7 @@ gotk export receiver [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_source.md b/docs/cmd/gotk_export_source.md
index 63278d5bdb9a63c2ea933b7b691ef0a60a0c715f..36b6bb9e2d99461c6a7c43cfb36c7625d1ad20ca 100644
--- a/docs/cmd/gotk_export_source.md
+++ b/docs/cmd/gotk_export_source.md
@@ -18,7 +18,7 @@ The export source sub-commands export sources in YAML format.
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_export_source_bucket.md b/docs/cmd/gotk_export_source_bucket.md
index 83b1b4fba1190e0e2223628ca148fcea527e7f55..d5a64173d911b48f5c3c384e4b83208bb781c7ef 100644
--- a/docs/cmd/gotk_export_source_bucket.md
+++ b/docs/cmd/gotk_export_source_bucket.md
@@ -32,7 +32,7 @@ gotk export source bucket [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
       --with-credentials    include credential secrets
diff --git a/docs/cmd/gotk_export_source_git.md b/docs/cmd/gotk_export_source_git.md
index f823d149c90599391bec99514723ede7b8921152..d6b6543a094b878e6358edf4199fa164022f65e9 100644
--- a/docs/cmd/gotk_export_source_git.md
+++ b/docs/cmd/gotk_export_source_git.md
@@ -32,7 +32,7 @@ gotk export source git [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
       --with-credentials    include credential secrets
diff --git a/docs/cmd/gotk_export_source_helm.md b/docs/cmd/gotk_export_source_helm.md
index 8bde4a57b92d0eb26217bb67eeb11d1e9dd39c57..de5c199fb163848b4430eb590c0d237f5d0a437d 100644
--- a/docs/cmd/gotk_export_source_helm.md
+++ b/docs/cmd/gotk_export_source_helm.md
@@ -32,7 +32,7 @@ gotk export source helm [name] [flags]
 ```
       --all                 select all resources
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
       --with-credentials    include credential secrets
diff --git a/docs/cmd/gotk_get.md b/docs/cmd/gotk_get.md
index 47f1ba0368f15b64305c234348da41ec864d75de..6910c36818310f8fdf7e0f1ec12ed914ec0d1b2d 100644
--- a/docs/cmd/gotk_get.md
+++ b/docs/cmd/gotk_get.md
@@ -17,7 +17,7 @@ The get sub-commands print the statuses of sources and resources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_alert-provider.md b/docs/cmd/gotk_get_alert-provider.md
index 0a4a889654f36f7fa367e18a9dae835c55a2ff4a..538eb2a1fb9fccd9cb7bbad053bcae4019c01e65 100644
--- a/docs/cmd/gotk_get_alert-provider.md
+++ b/docs/cmd/gotk_get_alert-provider.md
@@ -29,7 +29,7 @@ gotk get alert-provider [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_alert-providers.md b/docs/cmd/gotk_get_alert-providers.md
index e4827a67d05f64ed67fad0a283f0ac35df2805f7..70b2630186828661a268571864a2e178012bfb17 100644
--- a/docs/cmd/gotk_get_alert-providers.md
+++ b/docs/cmd/gotk_get_alert-providers.md
@@ -29,7 +29,7 @@ gotk get alert-providers [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_alert.md b/docs/cmd/gotk_get_alert.md
index 90457d4611af2d774b836672476828dc635e2336..e84945d882b5879a6f7691996972d89dd5d3df2f 100644
--- a/docs/cmd/gotk_get_alert.md
+++ b/docs/cmd/gotk_get_alert.md
@@ -29,7 +29,7 @@ gotk get alert [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_alerts.md b/docs/cmd/gotk_get_alerts.md
index 4a403d002d6f5e6c873fe208b96ddf60c4d72b64..0fe8bd03143cee38c852bcb0fdf15638260f9095 100644
--- a/docs/cmd/gotk_get_alerts.md
+++ b/docs/cmd/gotk_get_alerts.md
@@ -29,7 +29,7 @@ gotk get alerts [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_helmreleases.md b/docs/cmd/gotk_get_helmreleases.md
index b61d19bc8eac9ecc3385c98883f42655842010ff..4914d2d2e22a363c49b43887be21f8d106542718 100644
--- a/docs/cmd/gotk_get_helmreleases.md
+++ b/docs/cmd/gotk_get_helmreleases.md
@@ -29,7 +29,7 @@ gotk get helmreleases [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_kustomizations.md b/docs/cmd/gotk_get_kustomizations.md
index a8128f816d7e1a72868a03a90b1ff3a52756f6a9..0a539a2bafef03ad10a1ba23e2de09e86730d133 100644
--- a/docs/cmd/gotk_get_kustomizations.md
+++ b/docs/cmd/gotk_get_kustomizations.md
@@ -29,7 +29,7 @@ gotk get kustomizations [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_receiver.md b/docs/cmd/gotk_get_receiver.md
index e5de9e1c81a6dd623cf3e2f5d22e440b399fee12..ca034c47d19172113a23e8e18fd3961a0ecca2f9 100644
--- a/docs/cmd/gotk_get_receiver.md
+++ b/docs/cmd/gotk_get_receiver.md
@@ -29,7 +29,7 @@ gotk get receiver [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_receivers.md b/docs/cmd/gotk_get_receivers.md
index 211370c706266e2ca6ffc0b52c3afeefb2dc2c98..940772eb12c54d75ef470f1de446b527c883717d 100644
--- a/docs/cmd/gotk_get_receivers.md
+++ b/docs/cmd/gotk_get_receivers.md
@@ -29,7 +29,7 @@ gotk get receivers [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_sources.md b/docs/cmd/gotk_get_sources.md
index 5b8881db27e59168628c36386ad9dbb295563ebe..a33cf5cc5c9424d0d45e165cbff7fd86d99c4d50 100644
--- a/docs/cmd/gotk_get_sources.md
+++ b/docs/cmd/gotk_get_sources.md
@@ -17,7 +17,7 @@ The get source sub-commands print the statuses of the sources.
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_sources_bucket.md b/docs/cmd/gotk_get_sources_bucket.md
index 6f08b235a8a8eaf847ba5114bb2403cec666c280..092031fda3636854ba108b043b0408b6e1995677 100644
--- a/docs/cmd/gotk_get_sources_bucket.md
+++ b/docs/cmd/gotk_get_sources_bucket.md
@@ -29,7 +29,7 @@ gotk get sources bucket [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_sources_git.md b/docs/cmd/gotk_get_sources_git.md
index 7ec32b6ce8d0cb014ada1e9d0a9df7144b60868c..d6151837fb141bcf87571cc2bbfa010d4de672c7 100644
--- a/docs/cmd/gotk_get_sources_git.md
+++ b/docs/cmd/gotk_get_sources_git.md
@@ -29,7 +29,7 @@ gotk get sources git [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_get_sources_helm.md b/docs/cmd/gotk_get_sources_helm.md
index 9f2bc4525e9d453806a4519d1be413467a3a820f..500f9352928e5cf65bc1826f7f6ba3005ba09a61 100644
--- a/docs/cmd/gotk_get_sources_helm.md
+++ b/docs/cmd/gotk_get_sources_helm.md
@@ -29,7 +29,7 @@ gotk get sources helm [flags]
 ```
   -A, --all-namespaces      list the requested object(s) across all namespaces
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_install.md b/docs/cmd/gotk_install.md
index c66c24ded3556d8798a28a3127e738ef996f7346..1f0a01813a7bbb7f8c398ef2ea0cac0fe71b8d59 100644
--- a/docs/cmd/gotk_install.md
+++ b/docs/cmd/gotk_install.md
@@ -14,8 +14,8 @@ gotk install [flags]
 ### Examples
 
 ```
-  # Install the latest version in the gotk-system namespace
-  gotk install --version=latest --namespace=gotk-system
+  # Install the latest version in the flux-system namespace
+  gotk install --version=latest --namespace=flux-system
 
   # Dry-run install for a specific version and a series of components
   gotk install --dry-run --version=v0.0.7 --components="source-controller,kustomize-controller"
@@ -24,7 +24,7 @@ gotk install [flags]
   gotk install --dry-run --verbose
 
   # Write install manifests to file
-  gotk install --export > gotk-system.yaml
+  gotk install --export > flux-system.yaml
 
 ```
 
@@ -48,7 +48,7 @@ gotk install [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile.md b/docs/cmd/gotk_reconcile.md
index 9d4e3293788856be95c95aea13a53cdce8512580..8e8903fc6e7cd8f17590b9b278946b598b5b554c 100644
--- a/docs/cmd/gotk_reconcile.md
+++ b/docs/cmd/gotk_reconcile.md
@@ -16,7 +16,7 @@ The reconcile sub-commands trigger a reconciliation of sources and resources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_alert-provider.md b/docs/cmd/gotk_reconcile_alert-provider.md
index a8c3c2aa765bc16b2af54ba6cbb20e2c8e5feb02..05f392af4bb902180ba86c144eeba64976d70b3d 100644
--- a/docs/cmd/gotk_reconcile_alert-provider.md
+++ b/docs/cmd/gotk_reconcile_alert-provider.md
@@ -28,7 +28,7 @@ gotk reconcile alert-provider [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_alert.md b/docs/cmd/gotk_reconcile_alert.md
index 7a9244b9457f87a99c8838aba7f7f815b1be9f8f..388830bdc44f3c8b679120494b3d57e0c732162c 100644
--- a/docs/cmd/gotk_reconcile_alert.md
+++ b/docs/cmd/gotk_reconcile_alert.md
@@ -28,7 +28,7 @@ gotk reconcile alert [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_helmrelease.md b/docs/cmd/gotk_reconcile_helmrelease.md
index ca53dc501ab67c54bead30f7b44ae03bd05d28f5..f13cbd4faaf0f973228ec7caf4996b7b0fa624a9 100644
--- a/docs/cmd/gotk_reconcile_helmrelease.md
+++ b/docs/cmd/gotk_reconcile_helmrelease.md
@@ -33,7 +33,7 @@ gotk reconcile helmrelease [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_kustomization.md b/docs/cmd/gotk_reconcile_kustomization.md
index b9aa6dd823b01c466c104c31fd65b752da22b4f7..92ba2a3c4fe53734fea78d41608499718f23b2cc 100644
--- a/docs/cmd/gotk_reconcile_kustomization.md
+++ b/docs/cmd/gotk_reconcile_kustomization.md
@@ -33,7 +33,7 @@ gotk reconcile kustomization [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_receiver.md b/docs/cmd/gotk_reconcile_receiver.md
index 4072a478c2839a1e36ea62d14a37fdce7d53c323..c8499f5c1c87497db6e91fbb3d13b27dbd9b8013 100644
--- a/docs/cmd/gotk_reconcile_receiver.md
+++ b/docs/cmd/gotk_reconcile_receiver.md
@@ -28,7 +28,7 @@ gotk reconcile receiver [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_source.md b/docs/cmd/gotk_reconcile_source.md
index b731d111c1e3a116af2e0ef2aad6b8b9edd0a4e7..5fa64ff549775fad93d0c77e4de69fd8969fc3b8 100644
--- a/docs/cmd/gotk_reconcile_source.md
+++ b/docs/cmd/gotk_reconcile_source.md
@@ -16,7 +16,7 @@ The reconcile source sub-commands trigger a reconciliation of sources.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_source_bucket.md b/docs/cmd/gotk_reconcile_source_bucket.md
index 93372d24cd8c87d622a595692cf4b7ed44647fe8..997b40bd0f874b9787080b95c2b5bfa880b047a8 100644
--- a/docs/cmd/gotk_reconcile_source_bucket.md
+++ b/docs/cmd/gotk_reconcile_source_bucket.md
@@ -28,7 +28,7 @@ gotk reconcile source bucket [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_source_git.md b/docs/cmd/gotk_reconcile_source_git.md
index 9402e29dcbfbac062714fde60aa1b4154f9be2dc..90920796c01abd9ab375683ad49e438775bbabba 100644
--- a/docs/cmd/gotk_reconcile_source_git.md
+++ b/docs/cmd/gotk_reconcile_source_git.md
@@ -28,7 +28,7 @@ gotk reconcile source git [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_reconcile_source_helm.md b/docs/cmd/gotk_reconcile_source_helm.md
index fc78ab81bf3e19bebc48f3d1167ac31ad8eba91e..2e989b96ce518127cbb9597585173266b15b19cb 100644
--- a/docs/cmd/gotk_reconcile_source_helm.md
+++ b/docs/cmd/gotk_reconcile_source_helm.md
@@ -28,7 +28,7 @@ gotk reconcile source helm [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_resume.md b/docs/cmd/gotk_resume.md
index ed652fb14bf51118fd7c8ee94cd4128a54b0aafc..0607d4a05367d33e771589a78e23aeb7f89c5552 100644
--- a/docs/cmd/gotk_resume.md
+++ b/docs/cmd/gotk_resume.md
@@ -16,7 +16,7 @@ The resume sub-commands resume a suspended resource.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_resume_alert.md b/docs/cmd/gotk_resume_alert.md
index 81b5f9e96d2e000756b2d19a9fc5a4df228812ee..2e68792be75fb36d9ba7ab6aad0fdaede7110b03 100644
--- a/docs/cmd/gotk_resume_alert.md
+++ b/docs/cmd/gotk_resume_alert.md
@@ -29,7 +29,7 @@ gotk resume alert [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_resume_helmrelease.md b/docs/cmd/gotk_resume_helmrelease.md
index ac17e18d08dafaa8ac0bafaacad9a7f28ae8f530..351fc7d5a8324e67bae1ee74def32afe15dbec88 100644
--- a/docs/cmd/gotk_resume_helmrelease.md
+++ b/docs/cmd/gotk_resume_helmrelease.md
@@ -29,7 +29,7 @@ gotk resume helmrelease [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_resume_kustomization.md b/docs/cmd/gotk_resume_kustomization.md
index c1ca0074eec8e8c4eb4afa2cf9b9db4d3ab6206b..5f6fa7e3480b4e45da4e4cac017ea6f8b40dcee2 100644
--- a/docs/cmd/gotk_resume_kustomization.md
+++ b/docs/cmd/gotk_resume_kustomization.md
@@ -29,7 +29,7 @@ gotk resume kustomization [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_resume_receiver.md b/docs/cmd/gotk_resume_receiver.md
index eb3d231777edb5938bc0a4804d3250517687868a..56ff4b7b6d9382bd77e6c47774e7c11467364ecc 100644
--- a/docs/cmd/gotk_resume_receiver.md
+++ b/docs/cmd/gotk_resume_receiver.md
@@ -29,7 +29,7 @@ gotk resume receiver [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_suspend.md b/docs/cmd/gotk_suspend.md
index 157c19afc79b5ef7121af0ea224b894277d5025b..058bb93af6eb736ac1b8cfa83198f96097fbf4bd 100644
--- a/docs/cmd/gotk_suspend.md
+++ b/docs/cmd/gotk_suspend.md
@@ -16,7 +16,7 @@ The suspend sub-commands suspend the reconciliation of a resource.
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_suspend_alert.md b/docs/cmd/gotk_suspend_alert.md
index 13fc612945eda3f65fbe1ab89f31ed375482393a..c620ea894a98c522817ca2ddd6f516ff9ccb515b 100644
--- a/docs/cmd/gotk_suspend_alert.md
+++ b/docs/cmd/gotk_suspend_alert.md
@@ -28,7 +28,7 @@ gotk suspend alert [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_suspend_helmrelease.md b/docs/cmd/gotk_suspend_helmrelease.md
index 93c4c6d33f1431f25c3301db90ba3b73bd8e0fab..32703f6fd3c044c5b3cdc0879c81aa7b9521939a 100644
--- a/docs/cmd/gotk_suspend_helmrelease.md
+++ b/docs/cmd/gotk_suspend_helmrelease.md
@@ -28,7 +28,7 @@ gotk suspend helmrelease [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_suspend_kustomization.md b/docs/cmd/gotk_suspend_kustomization.md
index 0243112bec24958d3435ee2d157d7c1da09c987e..17e0cda08556e2dcdfbe59f3a20ce39a8ac2b2bb 100644
--- a/docs/cmd/gotk_suspend_kustomization.md
+++ b/docs/cmd/gotk_suspend_kustomization.md
@@ -28,7 +28,7 @@ gotk suspend kustomization [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_suspend_receiver.md b/docs/cmd/gotk_suspend_receiver.md
index af78dbf059f1e4aabb4a770667c8be1d0cc963af..f786239e025ab4c7b7b4a5ed18fadd891b0b9b37 100644
--- a/docs/cmd/gotk_suspend_receiver.md
+++ b/docs/cmd/gotk_suspend_receiver.md
@@ -28,7 +28,7 @@ gotk suspend receiver [name] [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/cmd/gotk_uninstall.md b/docs/cmd/gotk_uninstall.md
index 33df8898046c889596b051057d9c15b77d402bed..37a8617ff88d7e0a23cfa8b849e5ae92fe114f5d 100644
--- a/docs/cmd/gotk_uninstall.md
+++ b/docs/cmd/gotk_uninstall.md
@@ -14,10 +14,10 @@ gotk uninstall [flags]
 
 ```
   # Dry-run uninstall of all components
-  gotk uninstall --dry-run --namespace=gotk-system
+  gotk uninstall --dry-run --namespace=flux-system
 
   # Uninstall all components and delete custom resource definitions
-  gotk uninstall --resources --crds --namespace=gotk-system
+  gotk uninstall --resources --crds --namespace=flux-system
 
 ```
 
@@ -35,7 +35,7 @@ gotk uninstall [flags]
 
 ```
       --kubeconfig string   path to the kubeconfig file (default "~/.kube/config")
-  -n, --namespace string    the namespace scope for this operation (default "gotk-system")
+  -n, --namespace string    the namespace scope for this operation (default "flux-system")
       --timeout duration    timeout for this operation (default 5m0s)
       --verbose             print generated objects
 ```
diff --git a/docs/dev-guides/source-watcher.md b/docs/dev-guides/source-watcher.md
index 0c2f9cac52da58f9fec2dca3e8c484a720a288fe..39fff892781d50091b805c9f4acf6e95bf263c67 100644
--- a/docs/dev-guides/source-watcher.md
+++ b/docs/dev-guides/source-watcher.md
@@ -66,7 +66,7 @@ make
 Port forward to source-controller artifacts server:
 
 ```sh
-kubectl -n gotk-system port-forward svc/source-controller 8181:80
+kubectl -n flux-system port-forward svc/source-controller 8181:80
 ```
 
 Export the local address as `SOURCE_HOST`:
@@ -92,7 +92,7 @@ gotk create source git test \
 The source-watcher should log the revision:
 
 ```console
-New revision detected   {"gitrepository": "gotk-system/test", "revision": "4.0.0/ab953493ee14c3c9800bda0251e0c507f9741408"}
+New revision detected   {"gitrepository": "flux-system/test", "revision": "4.0.0/ab953493ee14c3c9800bda0251e0c507f9741408"}
 Extracted tarball into /var/folders/77/3y6x_p2j2g9fspdkzjbm5_s40000gn/T/test292235827: 123 files, 29 dirs (32.603415ms)
 Processing files...
 ```
@@ -108,7 +108,7 @@ gotk create source git test \
 The source-watcher should log the new revision:
 
 ```console
-New revision detected   {"gitrepository": "gotk-system/test", "revision": "4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27"}
+New revision detected   {"gitrepository": "flux-system/test", "revision": "4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27"}
 ```
 
 The source-controller reports the revision under `GitRepository.Status.Artifact.Revision` in the format: `<branch|tag>/<commit>`.
diff --git a/docs/get-started/index.md b/docs/get-started/index.md
index 8148f7661e6b39a93ab6c735a3176cf6e41070e0..03c6e031da13fadd44007b77c560cda5c11ae8dd 100644
--- a/docs/get-started/index.md
+++ b/docs/get-started/index.md
@@ -119,7 +119,7 @@ $ gotk bootstrap github --owner=gitopsrun --repository=fleet-infra --path=stagin
 ✔ repository cloned
 ✚ generating manifests
 ✔ components manifests pushed
-â–º installing components in gotk-system namespace
+â–º installing components in flux-system namespace
 deployment "source-controller" successfully rolled out
 deployment "kustomize-controller" successfully rolled out
 deployment "notification-controller" successfully rolled out
@@ -214,10 +214,10 @@ In about 30s the synchronization should start:
 ```console
 $ watch gotk get kustomizations
 NAME            REVISION                                        SUSPENDED       READY   MESSAGE
-gotk-system     main/6eea299fe9997c8561b826b67950afaf9a476cf8   False           True    Applied revision: main/6eea299fe9997c8561b826b67950afaf9a476cf8
-webapp-backend                                                  False           False   dependency 'gotk-system/webapp-common' is not ready
+flux-system     main/6eea299fe9997c8561b826b67950afaf9a476cf8   False           True    Applied revision: main/6eea299fe9997c8561b826b67950afaf9a476cf8
+webapp-backend                                                  False           False   dependency 'flux-system/webapp-common' is not ready
 webapp-common   master/7411da595c25183daba255068814b83843fe3395 False           True    Applied revision: master/7411da595c25183daba255068814b83843fe3395
-webapp-frontend                                                 False           False   dependency 'gotk-system/webapp-backend' is not ready
+webapp-frontend                                                 False           False   dependency 'flux-system/webapp-backend' is not ready
 ```
 
 When the synchronization finishes you can check that the webapp services are running:
@@ -311,22 +311,22 @@ List git sources:
 ```console
 $ gotk get sources git
 NAME            REVISION                                        READY   MESSAGE
-gotk-system     main/5ae055e24b2c8a78f981708b61507a97a30bd7a6   True    Fetched revision: main/113360052b3153e439a0cf8de76b8e3d2a7bdf27
+flux-system     main/5ae055e24b2c8a78f981708b61507a97a30bd7a6   True    Fetched revision: main/113360052b3153e439a0cf8de76b8e3d2a7bdf27
 webapp          4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27  True    Fetched revision: 4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27
 ```
 
-The kubectl equivalent is `kubectl -n gotk-system get gitrepositories`.
+The kubectl equivalent is `kubectl -n flux-system get gitrepositories`.
 
 List kustomization:
 
 ```console
 $ gotk get kustomizations
 NAME            REVISION                                        SUSPENDED       READY   MESSAGE
-gotk-system     main/5ae055e24b2c8a78f981708b61507a97a30bd7a6   False           True    Applied revision: main/5ae055e24b2c8a78f981708b61507a97a30bd7a6
+flux-system     main/5ae055e24b2c8a78f981708b61507a97a30bd7a6   False           True    Applied revision: main/5ae055e24b2c8a78f981708b61507a97a30bd7a6
 webapp          4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27  False           True    Applied revision: 4.0.1/113360052b3153e439a0cf8de76b8e3d2a7bdf27
 ```
 
-The kubectl equivalent is `kubectl -n gotk-system get kustomizations`.
+The kubectl equivalent is `kubectl -n flux-system get kustomizations`.
 
 If you want to upgrade to the latest 4.x version, you can change the semver expression to:
 
@@ -343,8 +343,8 @@ git add -A && git commit -m "update prod webapp" && git push
 Trigger a git sync:
 
 ```console
-$ gotk reconcile ks gotk-system --with-source 
-â–º annotating source gotk-system
+$ gotk reconcile ks flux-system --with-source 
+â–º annotating source flux-system
 ✔ source annotated
 â—Ž waiting for reconcilitation
 ✔ git reconciliation completed
@@ -354,13 +354,13 @@ $ gotk reconcile ks gotk-system --with-source
 ✔ applied revision main/d751ea264d48bf0db8b588d1d08184834ac8fec9
 ```
 
-The kubectl equivalent is `kubectl -n gotk-system annotate gitrepository/gotk-system fluxcd.io/reconcileAt="$(date +%s)"`.
+The kubectl equivalent is `kubectl -n flux-system annotate gitrepository/flux-system fluxcd.io/reconcileAt="$(date +%s)"`.
 
 Wait for the webapp to be upgraded:
 
 ```console
 $ watch gotk get kustomizations
 NAME            REVISION                                        SUSPENDED       READY   MESSAGE
-gotk-system     main/d751ea264d48bf0db8b588d1d08184834ac8fec9   False           True    Applied revision: main/d751ea264d48bf0db8b588d1d08184834ac8fec9
+flux-system     main/d751ea264d48bf0db8b588d1d08184834ac8fec9   False           True    Applied revision: main/d751ea264d48bf0db8b588d1d08184834ac8fec9
 webapp          4.0.6/26a630c0b4b3452833d96c511d93f6f2d2e90a99  False           True    Applied revision: 4.0.6/26a630c0b4b3452833d96c511d93f6f2d2e90a99
 ```
diff --git a/docs/guides/helmreleases.md b/docs/guides/helmreleases.md
index 434663648f03b68deed24007854c3fc70b84c5c8..4ddb006a81492e7562e2565be31be8630b1108f1 100644
--- a/docs/guides/helmreleases.md
+++ b/docs/guides/helmreleases.md
@@ -22,8 +22,8 @@ first to the source-controller, so that the `HelmRelease` can reference
 to it.
 
 A cluster administrator should register trusted sources by creating
-the resources in the `gotk-system` namespace. By default, the
-source-controller watches for sources only in the `gotk-system`
+the resources in the `flux-system` namespace. By default, the
+source-controller watches for sources only in the `flux-system`
 namespace, this way cluster admins can prevent untrusted sources from
 being registered by users.
 
@@ -43,7 +43,7 @@ apiVersion: source.toolkit.fluxcd.io/v1beta1
 kind: HelmRepository
 metadata:
   name: podinfo
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 1m
   url: https://stefanprodan.github.io/podinfo
@@ -82,7 +82,7 @@ apiVersion: source.toolkit.fluxcd.io/v1beta1
 kind: GitRepository
 metadata:
   name: podinfo
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 1m
   url: https://github.com/stefanprodan/podinfo
@@ -184,7 +184,7 @@ spec:
       sourceRef:
         kind: <HelmRepository|GitRepository|Bucket>
         name: podinfo
-        namespace: gotk-system
+        namespace: flux-system
       interval: 1m
   values:
     replicaCount: 2
@@ -265,7 +265,7 @@ broadcast events to the [notification-controller](../components/notification/con
 To receive the events as notifications, a `Provider` needs to be setup
 first as described in the [notifications guide](notifications.md#define-a-provider).
 Once you have set up the `Provider`, create a new `Alert` resource in
-the `gotk-system` to start receiving notifications about the Helm
+the `flux-system` to start receiving notifications about the Helm
 release:
 
 ```yaml
@@ -274,7 +274,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
   metadata:
     generation: 2
     name: helm-podinfo
-    namespace: gotk-system
+    namespace: flux-system
   spec:
     providerRef:
       name: slack
@@ -304,7 +304,7 @@ First generate a random string and create a secret with a `token` field:
 TOKEN=$(head -c 12 /dev/urandom | shasum | cut -d ' ' -f1)
 echo $TOKEN
 
-kubectl -n gotk-system create secret generic webhook-token \	
+kubectl -n flux-system create secret generic webhook-token \	
 --from-literal=token=$TOKEN
 ```
 
@@ -315,7 +315,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Receiver
 metadata:
   name: helm-podinfo
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   type: harbor
   secretRef:
@@ -330,7 +330,7 @@ The notification-controller generates a unique URL using the provided token and
 Find the URL with:
 
 ```console
-$ kubectl -n gotk-system get receiver/helm-podinfo
+$ kubectl -n flux-system get receiver/helm-podinfo
 
 NAME           READY   STATUS
 helm-podinfo   True    Receiver initialised with URL: /hook/bed6d00b5555b1603e1f59b94d7fdbca58089cb5663633fb83f2815dc626d92b
diff --git a/docs/guides/installation.md b/docs/guides/installation.md
index 748806be0f211df8d5cee23e4455bc6ca45e4c6c..0cfc3e439622cfd0d51b5590f665db6fc5fc84b0 100644
--- a/docs/guides/installation.md
+++ b/docs/guides/installation.md
@@ -75,12 +75,12 @@ cluster e.g. `staging-cluster` and `production-cluster`:
 
 ```sh
 ├── staging-cluster # <- path=staging-cluster
-│   └── gotk-system # <- namespace dir generated by bootstrap
+│   └── flux-system # <- namespace dir generated by bootstrap
 │       ├── toolkit-components.yaml
 │       ├── toolkit-kustomization.yaml
 │       └── toolkit-source.yaml
 └── production-cluster # <- path=production-cluster
-    └── gotk-system
+    └── flux-system
 ``` 
 
 !!! hint "Change the default branch"
@@ -205,7 +205,7 @@ cd my-repository
 Create a directory inside the repository:
 
 ```sh
-mkdir -p ./my-cluster/gotk-system
+mkdir -p ./my-cluster/flux-system
 ```
 
 Generate the toolkit manifests with:
@@ -213,7 +213,7 @@ Generate the toolkit manifests with:
 ```sh
 gotk install --version=latest \
   --arch=amd64 \ # on ARM64/AARCH64 clusters use --arch=arm64
-  --export > ./my-cluster/gotk-system/toolkit-components.yaml
+  --export > ./my-cluster/flux-system/toolkit-components.yaml
 ```
 
 If your cluster must pull images from a private container registry, first you should pull
@@ -225,12 +225,12 @@ docker tag ghcr.io/fluxcd/source-controller:v0.0.14 registry.internal/fluxcd/sou
 docker push registry.internal/fluxcd/source-controller:v0.0.14
 ```
 
-Create the pull secret in the `gotk-system` namespace:
+Create the pull secret in the `flux-system` namespace:
 
 ```sh
-kubectl create ns gotk-system
+kubectl create ns flux-system
 
-kubectl -n gotk-system create secret generic regcred \
+kubectl -n flux-system create secret generic regcred \
     --from-file=.dockerconfigjson=/.docker/config.json \
     --type=kubernetes.io/dockerconfigjson
 ```
@@ -241,7 +241,7 @@ Set your registry domain, and the pull secret when generating the manifests:
 gotk install --version=latest \
   --registry=registry.internal/fluxcd \
   --image-pull-secret=regcred \
-  --export > ./my-cluster/gotk-system/toolkit-components.yaml
+  --export > ./my-cluster/flux-system/toolkit-components.yaml
 ```
 
 Commit and push the manifest to the master branch:
@@ -253,7 +253,7 @@ git add -A && git commit -m "add toolkit manifests" && git push
 Apply the manifests on your cluster:
 
 ```sh
-kubectl apply -f ./my-cluster/gotk-system/toolkit-components.yaml
+kubectl apply -f ./my-cluster/flux-system/toolkit-components.yaml
 ```
 
 Verify that the toolkit controllers have started:
@@ -265,7 +265,7 @@ gotk check
 Create a `GitRepository` object on your cluster by specifying the SSH address of your repo:
 
 ```sh
-gotk create source git gotk-system \
+gotk create source git flux-system \
   --url= ssh://<host>/<org>/my-repository \
   --ssh-key-algorithm=ecdsa \
   --ssh-ecdsa-curve=p521 \
@@ -279,7 +279,7 @@ If you don't specify the SSH algorithm, then gotk will generate an RSA 2048 bits
 If your Git server supports basic auth, you can set the URL to HTTPS and specify the credentials with:
 
 ```sh
-gotk create source git gotk-system \
+gotk create source git flux-system \
   --url=https://<host>/<org>/my-repository \
   --username=my-username \
   --password=my-password \
@@ -290,8 +290,8 @@ gotk create source git gotk-system \
 Create a `Kustomization` object on your cluster:
 
 ```sh
-gotk create kustomization gotk-system \
-  --source=gotk-system \
+gotk create kustomization flux-system \
+  --source=flux-system \
   --path="./my-cluster" \
   --prune=true \
   --interval=10m
@@ -300,11 +300,11 @@ gotk create kustomization gotk-system \
 Export both objects, commit and push the manifests to Git:
 
 ```sh
-gotk export source git gotk-system \
-  > ./my-cluster/gotk-system/toolkit-source.yaml
+gotk export source git flux-system \
+  > ./my-cluster/flux-system/toolkit-source.yaml
 
-gotk export kustomization gotk-system \
-  > ./my-cluster/gotk-system/toolkit-kustomization.yaml
+gotk export kustomization flux-system \
+  > ./my-cluster/flux-system/toolkit-kustomization.yaml
 
 git add -A && git commit -m "add toolkit reconciliation" && git push
 ```
@@ -313,7 +313,7 @@ To upgrade the toolkit to a newer version, run the install command and commit th
 
 ```sh
 gotk install --version=latest \
-  --export > ./my-cluster/gotk-system/toolkit-components.yaml
+  --export > ./my-cluster/flux-system/toolkit-components.yaml
 
 git add -A && git commit -m "update toolkit" && git push
 ```
@@ -367,7 +367,7 @@ gotk create source helm stable \
 gotk create helmrelease sealed-secrets \
   --interval=1h \
   --release-name=sealed-secrets \
-  --target-namespace=gotk-system \
+  --target-namespace=flux-system \
   --source=HelmRepository/stable \
   --chart=sealed-secrets \
   --chart-version="1.10.x"
diff --git a/docs/guides/monitoring.md b/docs/guides/monitoring.md
index 46964f26cd5a275590e6ecdb847df264dfd26d91..80adb113fedc2398eaa377ba789cd9ec7ac65523 100644
--- a/docs/guides/monitoring.md
+++ b/docs/guides/monitoring.md
@@ -27,14 +27,14 @@ gotk create kustomization monitoring \
   --prune=true \
   --source=monitoring \
   --path="./manifests/monitoring" \
-  --health-check="Deployment/prometheus.gotk-system" \
-  --health-check="Deployment/grafana.gotk-system"
+  --health-check="Deployment/prometheus.flux-system" \
+  --health-check="Deployment/grafana.flux-system"
 ```
 
 You can access Grafana using port forwarding:
 
 ```sh
-kubectl -n gotk-system port-forward svc/grafana 3000:3000
+kubectl -n flux-system port-forward svc/grafana 3000:3000
 ```
 
 ## Grafana dashboards
diff --git a/docs/guides/mozilla-sops.md b/docs/guides/mozilla-sops.md
index a13a13b2d4f6e504e0b29f861cfefdf2af72e0ff..37d9326da038935a6e20e9b215025968deb2ba49 100644
--- a/docs/guides/mozilla-sops.md
+++ b/docs/guides/mozilla-sops.md
@@ -41,13 +41,13 @@ sec   rsa3072 2020-09-06 [SC]
 ```
 
 Export the public and private keypair from your local GPG keyring and
-create a Kubernetes secret named `sops-gpg` in the `gotk-system` namespace:
+create a Kubernetes secret named `sops-gpg` in the `flux-system` namespace:
 
 ```sh
 gpg --export-secret-keys \
 --armor 1F3D1CED2F865F5E59CA564553241F147E7C5FA4 |
 kubectl create secret generic sops-gpg \
---namespace=gotk-system \
+--namespace=flux-system \
 --from-file=sops.asc=/dev/stdin 
 ```
 
@@ -104,7 +104,7 @@ secrets by iterating over all the private keys until it finds one that works.
 !!! hint KMS
     When using AWS/GCP KMS or Azure Key Vault, you'll have to bind an IAM Role
     with read access to the KMS keys to the `default` service account of the
-    `gotk-system` namespace for kustomize-controller to be able to fetch
+    `flux-system` namespace for kustomize-controller to be able to fetch
     keys from KMS.
 
 ## GitOps workflow
@@ -119,7 +119,7 @@ apiVersion: source.toolkit.fluxcd.io/v1beta1
 kind: GitRepository
 metadata:
   name: my-secrets
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 1m
   url: https://github.com/my-org/my-secrets
@@ -132,7 +132,7 @@ apiVersion: kustomize.toolkit.fluxcd.io/v1beta1
 kind: Kustomization
 metadata:
   name: my-secrets
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 10m0s
   sourceRef:
diff --git a/docs/guides/notifications.md b/docs/guides/notifications.md
index de9b4811f6605ac57da48d4012dfb5fb5d6b1b8a..e7e2090ac54c9280f78df70df01812cfe7dab13d 100644
--- a/docs/guides/notifications.md
+++ b/docs/guides/notifications.md
@@ -23,7 +23,7 @@ The notification controller is part of the default toolkit installation.
 First create a secret with your Slack incoming webhook:
 
 ```sh
-kubectl -n gotk-system create secret generic slack-url \
+kubectl -n flux-system create secret generic slack-url \
 --from-literal=address=https://hooks.slack.com/services/YOUR/SLACK/WEBHOOK
 ```
 
@@ -37,7 +37,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Provider
 metadata:
   name: slack
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   type: slack
   channel: general
@@ -61,7 +61,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Alert
 metadata:
   name: on-call-webapp
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   providerRef:
     name: slack
@@ -78,7 +78,7 @@ Apply the above files or commit them to the `fleet-infra` repository.
 To verify that the alert has been acknowledge by the notification controller do:
 
 ```console
-$ kubectl -n gotk-system get alerts
+$ kubectl -n flux-system get alerts
 
 NAME             READY   STATUS        AGE
 on-call-webapp   True    Initialized   1m
@@ -141,7 +141,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Provider
 metadata:
   name: podinfo
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   type: github
   channel: general
@@ -153,7 +153,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Alert
 metadata:
   name: podinfo
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   providerRef:
     name: podinfo
@@ -161,7 +161,7 @@ spec:
   eventSources:
     - kind: Kustomization
       name: podinfo
-      namespace: gotk-system
+      namespace: flux-system
 ```
 
 The secret referenced in the provider is expected to contain a [personal access token](https://docs.github.com/en/github/authenticating-to-github/creating-a-personal-access-token)
@@ -171,7 +171,7 @@ apiVersion: v1
 kind: Secret
 metadata:
   name: github
-  namespace: gotk-system
+  namespace: flux-system
 data:
   token: <token>
 ```
diff --git a/docs/guides/sealed-secrets.md b/docs/guides/sealed-secrets.md
index 58ba8b098cfa026cf49f15c37283d1774aeb33f0..6a86d3612214ce6563943e10e97a03cdc96771fb 100644
--- a/docs/guides/sealed-secrets.md
+++ b/docs/guides/sealed-secrets.md
@@ -49,7 +49,7 @@ Create a Helm release that installs the latest version of sealed-secrets control
 gotk create helmrelease sealed-secrets \
 --interval=1h \
 --release-name=sealed-secrets \
---target-namespace=gotk-system \
+--target-namespace=flux-system \
 --source=HelmRepository/stable \
 --chart=sealed-secrets \
 --chart-version="1.10.x"
@@ -59,14 +59,14 @@ With chart version `1.10.x` we configure helm-controller to automatically upgrad
 when a new chart patch version is fetched by source-controller.
 
 At startup, the sealed-secrets controller generates a 4096-bit RSA key pair and 
-persists the private and public keys as Kubernetes secrets in the `gotk-system` namespace.
+persists the private and public keys as Kubernetes secrets in the `flux-system` namespace.
 
 You can retrieve the public key with:
 
 ```sh
 kubeseal --fetch-cert \
 --controller-name=sealed-secrets \
---controller-namespace=gotk-system \
+--controller-namespace=flux-system \
 > pub-sealed-secrets.pem
 ``` 
 
@@ -120,7 +120,7 @@ apiVersion: source.toolkit.fluxcd.io/v1beta1
 kind: HelmRepository
 metadata:
   name: stable
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 1h0m0s
   url: https://charts.helm.sh/stable
@@ -133,7 +133,7 @@ apiVersion: helm.toolkit.fluxcd.io/v2beta1
 kind: HelmRelease
 metadata:
   name: sealed-secrets
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   chart:
     spec:
@@ -144,7 +144,7 @@ spec:
       version: "1.10.x"
   interval: 1h0m0s
   releaseName: sealed-secrets
-  targetNamespace: gotk-system
+  targetNamespace: flux-system
 ```
 
 !!! hint
diff --git a/docs/guides/webhook-receivers.md b/docs/guides/webhook-receivers.md
index 3eb010a3e28e31705adc82a2f968eebbd48d271e..d31fdb954b7752be7b7d5e3f84e0ac0cc7dd1d67 100644
--- a/docs/guides/webhook-receivers.md
+++ b/docs/guides/webhook-receivers.md
@@ -35,7 +35,7 @@ apiVersion: v1
 kind: Service
 metadata:
   name: receiver
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   type: LoadBalancer
   selector:
@@ -50,7 +50,7 @@ spec:
 Wait for Kubernetes to assign a public address with:
 
 ```sh
-watch kubectl -n gotk-system get svc/receiver
+watch kubectl -n flux-system get svc/receiver
 ``` 
 
 ## Define a Git repository
@@ -62,7 +62,7 @@ apiVersion: source.toolkit.fluxcd.io/v1beta1
 kind: GitRepository
 metadata:
   name: webapp
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   interval: 60m
   url: https://github.com/<GH-ORG>/<GH-REPO>
@@ -82,7 +82,7 @@ First generate a random string and create a secret with a `token` field:
 TOKEN=$(head -c 12 /dev/urandom | shasum | cut -d ' ' -f1)
 echo $TOKEN
 
-kubectl -n gotk-system create secret generic webhook-token \	
+kubectl -n flux-system create secret generic webhook-token \	
 --from-literal=token=$TOKEN
 ```
 
@@ -93,7 +93,7 @@ apiVersion: notification.toolkit.fluxcd.io/v1beta1
 kind: Receiver
 metadata:
   name: webapp
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   type: github
   events:
@@ -116,7 +116,7 @@ The notification controller generates a unique URL using the provided token and
 Find the URL with:
 
 ```console
-$ kubectl -n gotk-system get receiver/webapp
+$ kubectl -n flux-system get receiver/webapp
 
 NAME     READY   STATUS
 webapp   True    Receiver initialised with URL: /hook/bed6d00b5555b1603e1f59b94d7fdbca58089cb5663633fb83f2815dc626d92b
diff --git a/manifests/install/kustomization.yaml b/manifests/install/kustomization.yaml
index d0c76702925ede367415794165dca980e49d9309..65b57db72c6f495a2815983a00afbed1078ad6d6 100644
--- a/manifests/install/kustomization.yaml
+++ b/manifests/install/kustomization.yaml
@@ -1,6 +1,6 @@
 apiVersion: kustomize.config.k8s.io/v1beta1
 kind: Kustomization
-namespace: gotk-system
+namespace: flux-system
 resources:
   - namespace.yaml
   - ../bases/source-controller
diff --git a/manifests/install/labels.yaml b/manifests/install/labels.yaml
index ca512d490491c9540892f903b79e5b4e4dc384e8..9613b10f14c463274342064cd30121f6e70ec74a 100644
--- a/manifests/install/labels.yaml
+++ b/manifests/install/labels.yaml
@@ -3,7 +3,7 @@ kind: LabelTransformer
 metadata:
   name: labels
 labels:
-  app.kubernetes.io/instance: gotk-system
+  app.kubernetes.io/instance: flux-system
 fieldSpecs:
   - path: metadata/labels
     create: true
diff --git a/manifests/install/namespace.yaml b/manifests/install/namespace.yaml
index 69408c5b6dbf8bd849fc490472be204c2350534d..c00a4321ea2d40a7fbda43f70f55baf7481fc6b0 100644
--- a/manifests/install/namespace.yaml
+++ b/manifests/install/namespace.yaml
@@ -1,4 +1,4 @@
 apiVersion: v1
 kind: Namespace
 metadata:
-  name: gotk-system
+  name: flux-system
diff --git a/manifests/monitoring/grafana/dashboards/control-plane.json b/manifests/monitoring/grafana/dashboards/control-plane.json
index 9535a70c8e15734f3376c63c854a09e446b42e63..620451ad3fcf037c8debded7c024262fc9730dca 100644
--- a/manifests/monitoring/grafana/dashboards/control-plane.json
+++ b/manifests/monitoring/grafana/dashboards/control-plane.json
@@ -1382,8 +1382,8 @@
         "allValue": null,
         "current": {
           "selected": false,
-          "text": "gotk-system",
-          "value": "gotk-system"
+          "text": "flux-system",
+          "value": "flux-system"
         },
         "datasource": "${DS_PROMETHEUS}",
         "definition": "workqueue_work_duration_seconds_count",
diff --git a/manifests/monitoring/grafana/datasources.yaml b/manifests/monitoring/grafana/datasources.yaml
index e308db56963b64a1d892eae3d67b128f36286f79..f3961d19ce096e90a8f9c7d53f9db9d97cc70940 100644
--- a/manifests/monitoring/grafana/datasources.yaml
+++ b/manifests/monitoring/grafana/datasources.yaml
@@ -2,7 +2,7 @@ apiVersion: v1
 kind: ConfigMap
 metadata:
   name: grafana-datasources
-  namespace: gotk-system
+  namespace: flux-system
 data:
   datasources.yaml: |-
     apiVersion: 1
diff --git a/manifests/monitoring/grafana/kustomization.yaml b/manifests/monitoring/grafana/kustomization.yaml
index ed0e7d029feb950a4d2912e49d70c88b7889912f..13e0356a11c1a11e675c3f0e1f5f5180213e05a9 100644
--- a/manifests/monitoring/grafana/kustomization.yaml
+++ b/manifests/monitoring/grafana/kustomization.yaml
@@ -1,6 +1,6 @@
 apiVersion: kustomize.config.k8s.io/v1beta1
 kind: Kustomization
-namespace: gotk-system
+namespace: flux-system
 resources:
   - service.yaml
   - deployment.yaml
diff --git a/manifests/monitoring/grafana/providers.yaml b/manifests/monitoring/grafana/providers.yaml
index dfca8d1b845c0b956ae2e5756974e12a74a6b351..4f5e23c9e4f259076c856476f701f24e7e6e9f57 100644
--- a/manifests/monitoring/grafana/providers.yaml
+++ b/manifests/monitoring/grafana/providers.yaml
@@ -2,7 +2,7 @@ apiVersion: v1
 kind: ConfigMap
 metadata:
   name: grafana-providers
-  namespace: gotk-system
+  namespace: flux-system
 data:
   providers.yaml: |+
     apiVersion: 1
diff --git a/manifests/monitoring/grafana/service.yaml b/manifests/monitoring/grafana/service.yaml
index c59bcfbad88bef0963a8130c111210f20bdd59c2..87968d71ab3d5e87cbc82df8420f8ee1a0e05e31 100644
--- a/manifests/monitoring/grafana/service.yaml
+++ b/manifests/monitoring/grafana/service.yaml
@@ -2,7 +2,7 @@ apiVersion: v1
 kind: Service
 metadata:
   name: grafana
-  namespace: gotk-system
+  namespace: flux-system
   labels:
     app: grafana
 spec:
diff --git a/manifests/monitoring/kustomization.yaml b/manifests/monitoring/kustomization.yaml
index ea99762869fce50c9c9248ceca1f72992ebc36e1..b93baa2d392696b271f6bc81c501998acd486d39 100644
--- a/manifests/monitoring/kustomization.yaml
+++ b/manifests/monitoring/kustomization.yaml
@@ -1,6 +1,6 @@
 apiVersion: kustomize.config.k8s.io/v1beta1
 kind: Kustomization
-namespace: gotk-system
+namespace: flux-system
 resources:
 - prometheus
 - grafana
diff --git a/manifests/monitoring/prometheus/account.yaml b/manifests/monitoring/prometheus/account.yaml
index eb893a67729a7014c8cd6f204dd5b1274c5b01c8..e475c19605e49a4ace7c1c8d2e89f8e8649a3bd0 100644
--- a/manifests/monitoring/prometheus/account.yaml
+++ b/manifests/monitoring/prometheus/account.yaml
@@ -2,4 +2,4 @@ apiVersion: v1
 kind: ServiceAccount
 metadata:
   name: prometheus
-  namespace: gotk-system
+  namespace: flux-system
diff --git a/manifests/monitoring/prometheus/deployment.yaml b/manifests/monitoring/prometheus/deployment.yaml
index 34e7055142fe30de87fe1ef6aefc20e9e5fda0d9..355986d8e773f4a216b76a20533a11c8ade1eb0f 100644
--- a/manifests/monitoring/prometheus/deployment.yaml
+++ b/manifests/monitoring/prometheus/deployment.yaml
@@ -2,7 +2,7 @@ apiVersion: apps/v1
 kind: Deployment
 metadata:
   name: prometheus
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   replicas: 1
   selector:
diff --git a/manifests/monitoring/prometheus/kustomization.yaml b/manifests/monitoring/prometheus/kustomization.yaml
index e6612a613b6feb0149278ae3028b63e229cdacda..b3377956f69a931d77d2ced5b5c6f90ec3402682 100644
--- a/manifests/monitoring/prometheus/kustomization.yaml
+++ b/manifests/monitoring/prometheus/kustomization.yaml
@@ -1,6 +1,6 @@
 apiVersion: kustomize.config.k8s.io/v1beta1
 kind: Kustomization
-namespace: gotk-system
+namespace: flux-system
 resources:
   - account.yaml
   - rbac.yaml
diff --git a/manifests/monitoring/prometheus/rbac.yaml b/manifests/monitoring/prometheus/rbac.yaml
index 05fac6f878a404408f8d5bdc151206699a59af14..926a6d8396703c5710dccbefba2c495e3730b9e3 100644
--- a/manifests/monitoring/prometheus/rbac.yaml
+++ b/manifests/monitoring/prometheus/rbac.yaml
@@ -1,7 +1,7 @@
 apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRole
 metadata:
-  name: prometheus-gotk-system
+  name: prometheus-flux-system
 rules:
   - apiGroups: [""]
     resources:
@@ -21,12 +21,12 @@ rules:
 apiVersion: rbac.authorization.k8s.io/v1
 kind: ClusterRoleBinding
 metadata:
-  name: prometheus-gotk-system
+  name: prometheus-flux-system
 roleRef:
   apiGroup: rbac.authorization.k8s.io
   kind: ClusterRole
-  name: prometheus-gotk-system
+  name: prometheus-flux-system
 subjects:
 - kind: ServiceAccount
   name: prometheus
-  namespace: gotk-system
+  namespace: flux-system
diff --git a/manifests/monitoring/prometheus/service.yaml b/manifests/monitoring/prometheus/service.yaml
index 1b72bb084c0b33471641b5e0f65af6500fb46545..143cd9b410909abcfbc172fe51c152500789b329 100644
--- a/manifests/monitoring/prometheus/service.yaml
+++ b/manifests/monitoring/prometheus/service.yaml
@@ -2,7 +2,7 @@ apiVersion: v1
 kind: Service
 metadata:
   name: prometheus
-  namespace: gotk-system
+  namespace: flux-system
 spec:
   selector:
     app: prometheus
diff --git a/pkg/manifestgen/install/options.go b/pkg/manifestgen/install/options.go
index ab5c4de496e7948bacafd5b238f087aa12c7927c..e5bd060296e4ac2541412948bcecd6ae4751f9dc 100644
--- a/pkg/manifestgen/install/options.go
+++ b/pkg/manifestgen/install/options.go
@@ -39,7 +39,7 @@ type Options struct {
 func MakeDefaultOptions() Options {
 	return Options{
 		Version:                "latest",
-		Namespace:              "gotk-system",
+		Namespace:              "flux-system",
 		Components:             []string{"source-controller", "kustomize-controller", "helm-controller", "notification-controller"},
 		EventsAddr:             "",
 		Registry:               "ghcr.io/fluxcd",
diff --git a/pkg/manifestgen/sync/options.go b/pkg/manifestgen/sync/options.go
index 20de1a38c0e889f8d6cf61feda86bd100f9bb2fc..a2739034022f3fba892f096c1754da39224863d4 100644
--- a/pkg/manifestgen/sync/options.go
+++ b/pkg/manifestgen/sync/options.go
@@ -32,10 +32,10 @@ func MakeDefaultOptions() Options {
 	return Options{
 		Interval:     1 * time.Minute,
 		URL:          "",
-		Name:         "gotk-system",
-		Namespace:    "gotk-system",
+		Name:         "flux-system",
+		Namespace:    "flux-system",
 		Branch:       "main",
-		ManifestFile: "gotk-sync.yaml",
+		ManifestFile: "flux-sync.yaml",
 		TargetPath:   "",
 	}
 }
diff --git a/cmd/gotk/install.go b/cmd/gotk/install.go
index 7c03786505e16abf91638580c4e29b81c5528601..03e835d9b93f31545b55e6ff7dfc78385f18ba75 100644
--- a/cmd/gotk/install.go
+++ b/cmd/gotk/install.go
@@ -36,8 +36,8 @@ var installCmd = &cobra.Command{
 	Short: "Install the toolkit components",
 	Long: `The install command deploys the toolkit components in the specified namespace.
 If a previous version is installed, then an in-place upgrade will be performed.`,
-	Example: `  # Install the latest version in the gotk-system namespace
-  gotk install --version=latest --namespace=gotk-system
+	Example: `  # Install the latest version in the flux-system namespace
+  gotk install --version=latest --namespace=flux-system
 
   # Dry-run install for a specific version and a series of components
   gotk install --dry-run --version=v0.0.7 --components="source-controller,kustomize-controller"
@@ -46,7 +46,7 @@ If a previous version is installed, then an in-place upgrade will be performed.`
   gotk install --dry-run --verbose
 
   # Write install manifests to file
-  gotk install --export > gotk-system.yaml
+  gotk install --export > flux-system.yaml
 `,
 	RunE: installCmdRun,
 }